<?php
// $Id: drupal_developer.profile,v 1.6.2.6.2.2 2010/03/23 18:09:51 snufkin Exp $
/**
 * @file
 * Install profile for a developer setup
 */

/**
 * Return an array of the modules to be enabled when this profile is installed.
 *
 * @return
 *   An array of modules to enable.
 */
function drupal_developer_profile_modules() {
  return array(
    // Enable core modules.
    'block', 'user', 'filter', 'block', 'node', 'taxonomy', 'comment', 'menu', 'dblog', 'system', 'path',
    // Enable admin menu.
    'admin_menu',
  );
}

function drupal_developer_profile_details() {
  return array(
    'name' => 'Drupal developer profile',
    'description' => 'Install and set up quick development setup. WARNING! It contains dangerous user permissions, for development purposes only.',
  );
}

function drupal_developer_profile_tasks(&$task, $url) {
  $output = '';
  
  if (in_array($task, array('developer-modules-batch', 'developer-configure-batch'))) {
    include_once 'includes/batch.inc';
    $output = _batch_page();
  }
  
  $modules = _developer_modules();
  $files = module_rebuild_cache();
  
  if ('profile' == $task) {
    
    foreach ($modules as $module) {
      $batch['operations'][] = array('_install_module_batch', array($module, $files[$module->info['name']]));
    }
    
    $batch['title'] = st('Installing @drupal', array('@drupal' => drupal_install_profile_name()));
		$batch['finished'] = '_developer_batch_finished';
	 	$batch['error_message'] = st('The installation has encountered an error.');
	 	
	 	// Start a batch, switch to 'developer-modules-batch' task. We need to
	 	// set the variable here, because batch_process() redirects.
	 	variable_set('install_task', 'developer-modules-batch');
	 	batch_set($batch);
	 	batch_process($url, $url);
	 	// Jut for cli installs. We'll never reach here on interactive installs.
		return;
  }
  
  if ('profile-configure' == $task) {
	 	$batch['title'] = st('Configuring @drupal', array('@drupal' => drupal_install_profile_name()));
 		$batch['operations'][] = array('_developer_configure', array());
	 	$batch['operations'][] = array('_developer_configure_check', array());
	 	$batch['finished'] = '_developer_configure_finished';
	 	variable_set('install_task', 'developer-configure-batch');
	 	batch_set($batch);
	 	batch_process($url, $url);
	 	// Jut for cli installs. We'll never reach here on interactive installs.
	 	return;
	}
	
	return $output;
}

function _developer_batch_finished($success, $result) {
  variable_set('install_task', 'profile-configure');
}

function _developer_configure() {
  // Don't display date and author information for page nodes by default.
  $theme_settings = variable_get('theme_settings', array());
  $theme_settings['toggle_node_info_page'] = FALSE;
  variable_set('theme_settings', $theme_settings);
}

function _developer_configure_check() {
  node_access_rebuild();
	_block_rehash(); // Populate the blocks table so we can update.
	
	// Rebuild key tables/caches
	drupal_flush_all_caches();
  db_query("UPDATE {blocks} SET status = 0, region = ''"); // disable all DB blocks
  // Devel blocks
	db_query("UPDATE {blocks} SET status = 1, region = 'left', theme = 'garland' WHERE module = 'devel' AND delta = 0");
	db_query("UPDATE {blocks} SET status = 1, region = 'left', theme = 'garland' WHERE module = 'devel' AND delta = 1");
	db_query("UPDATE {blocks} SET status = 1, region = 'footer', theme = 'garland' WHERE module = 'devel' AND delta = 2");
	db_query("UPDATE {blocks} SET status = 1, region = 'left', theme = 'garland' WHERE module = 'menu' AND delta = 'devel'");
  // User blocks
	db_query("UPDATE {blocks} SET status = 1, region = 'left', theme = 'garland', weight = -3 WHERE module = 'user' AND delta = 0");
	db_query("UPDATE {blocks} SET status = 1, region = 'left', theme = 'garland', weight = -5 WHERE module = 'user' AND delta = 1");
    		
  // Configure settings.
  // Save any old SMTP library
  $smtp_old = variable_get('smtp_library', '');
  $smtp_new = drupal_get_filename('module', 'devel');
  if ($smtp_old != '' && $smtp_old != $smtp_new) {
    variable_set('devel_old_smtp_library', $smtp_old);
  }
  variable_set('smtp_library', $smtp_new);
  // Make sure the switch user block is big enough for all the
  // auto-generated users on the site.
  variable_set('devel_switch_user_list_size', 15);
}

function _developer_configure_finished() {
  variable_set('install_task', 'profile-finished');
}

function _developer_modules() {
  return array(
    'strongarm', 'devel', 'devel_generate', 'coder', 'ctools',
  );
}


/**
 * Make this install profile the default.
 */
function system_form_install_select_profile_form_alter(&$form, $form_state) {
	foreach($form['profile'] as $key => $element) {
		$form['profile'][$key]['#value'] = 'drupal_developer';
	}
}


/**
 * Make the configuration form a little speedier.
 */
function system_form_install_configure_form_alter(&$form, $form_state) {
  drupal_set_message(t('Configuration is provided by the profile. Username: admin, password: drupal.'), 'notice');
  $form['site_information']['#collapsible'] = TRUE;
  $form['site_information']['#collapsed'] = TRUE;
 	$form['site_information']['site_name']['#default_value'] = 'Drupal Devel';
 	$form['site_information']['site_mail']['#default_value'] = 'admin@'. $_SERVER['HTTP_HOST'];

  $form['admin_account']['#collapsible'] = TRUE;
  $form['admin_account']['#collapsed'] = TRUE;
 	$form['admin_account']['account']['name']['#default_value'] = 'admin';
 	$form['admin_account']['account']['mail']['#default_value'] = 'admin@'. $_SERVER['HTTP_HOST'];
	$form['admin_account']['account']['pass'] = array(
		'#value' => 'drupal',
		'#type' => 'value',
	);
}

function _install_node_types() {
  // Insert default user-defined node types into the database. For a complete
  // list of available node type attributes, refer to the node type API
  // documentation at: http://api.drupal.org/api/HEAD/function/hook_node_info.
  $types = array(
    array(
      'type' => 'page',
      'name' => st('Page'),
      'module' => 'node',
      'description' => st("A <em>page</em>, similar in form to a <em>story</em>, is a simple method for creating and displaying information that rarely changes, such as an \"About us\" section of a website. By default, a <em>page</em> entry does not allow visitor comments and is not featured on the site's initial home page."),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
      'help' => '',
      'min_word_count' => '',
    ),
    array(
      'type' => 'story',
      'name' => st('Story'),
      'module' => 'node',
      'description' => st("A <em>story</em>, similar in form to a <em>page</em>, is ideal for creating and displaying content that informs or engages website visitors. Press releases, site announcements, and informal blog-like entries may all be created with a <em>story</em> entry. By default, a <em>story</em> entry is automatically featured on the site's initial home page, and provides the ability to post comments."),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
      'help' => '',
      'min_word_count' => '',
    ),
  );

  foreach ($types as $type) {
    $type = (object) _node_type_set_defaults($type);
    node_type_save($type);
  }

  // Default page to not be promoted and have comments disabled.
  variable_set('node_options_page', array('status'));
  variable_set('comment_page', COMMENT_NODE_DISABLED);
}

